<?php

// Require
require_once 'Cron/autoload.php';
require_once 'Dotenv/autoload.php';
require_once 'FastRoute/autoload.php';
require_once 'Illuminate/Auth/autoload.php';
require_once 'Illuminate/Broadcasting/autoload.php';
require_once 'Illuminate/Bus/autoload.php';
require_once 'Illuminate/Cache/autoload.php';
require_once 'Illuminate/Config/autoload.php';
require_once 'Illuminate/Container/autoload.php';
require_once 'Illuminate/Contracts/autoload.php';
require_once 'Illuminate/Database/autoload.php';
require_once 'Illuminate/Encryption/autoload.php';
require_once 'Illuminate/Events/autoload.php';
require_once 'Illuminate/Filesystem/autoload.php';
require_once 'Illuminate/Hashing/autoload.php';
require_once 'Illuminate/Http/autoload.php';
require_once 'Illuminate/Log/autoload.php';
require_once 'Illuminate/Pagination/autoload.php';
require_once 'Illuminate/Pipeline/autoload.php';
require_once 'Illuminate/Queue/autoload.php';
require_once 'Illuminate/Support/autoload.php';
require_once 'Illuminate/Translation/autoload.php';
require_once 'Illuminate/Validation/autoload.php';
require_once 'Illuminate/View/autoload.php';
require_once 'Symfony/Component/HttpFoundation/autoload.php';
require_once 'Symfony/Component/HttpKernel/autoload.php';
require_once 'Symfony/Component/VarDumper/autoload.php';

// Suggest
# Missing: symfony/psr-http-message-bridge
if (stream_resolve_include_path('Laravel/Tinker/autoload.php')) { include_once 'Laravel/Tinker/autoload.php'; }
if (stream_resolve_include_path('Nyholm/Psr7/autoload.php')) { include_once 'Nyholm/Psr7/autoload.php'; }

// Files
require_once __DIR__.'/helpers.php';

// @codingStandardsIgnoreFile
// @codeCoverageIgnoreStart
// this is an autogenerated file - do not edit
spl_autoload_register(
    function($class) {
        static $classes = null;
        if ($classes === null) {
            $classes = array(
                ___CLASSLIST___
            );
        }
        $cn = strtolower($class);
        if (isset($classes[$cn])) {
            require ___BASEDIR___$classes[$cn];
        }
    },
    ___EXCEPTION___,
    ___PREPEND___
);
// @codeCoverageIgnoreEnd
